// 包括库	--- Include libraries
#include <stdio.h>

// 定义		--- Definitions
#define N 15 		// 空间网格数	--- Number of spatial grid points
#define T 30   		// 时间步数	--- Time steps to be simulated (integrated)
#define dt 1 		// 时间步长	--- Temporal length scale (dt)
#define dx 1 		// 空间步长	--- Spatial length scale （dx
#define alpha 0.1 	// 扩散系数	--- Diffusion coefficient


// 打印功能	--- Print function
void printGrid(double grid[N]) {
	   for (int i = 0; i < N;i++){
		 printf("%.2f ", grid[i]);
                 printf("\t");
						        }
			            printf("\n");
}


// 主要功能	--- Main function
int main() {
    double u[N+1];	// u： 为当前时刻的浓度分
			//	--- To store the concentration distribution at the current moment
    double u_new[N+1];	// u_new： 为下一个时刻的浓度分布
			//	--- To sdtore the concentration distribution at the next moment

    // 初始化浓度分布		--- Initialize concentration distribution
    for (int i = 0; i <= N; i++) {
        if (i >= 45*N/100 && i <= 55*N/100) {
            u[i] = 100.0;
        } else {
            u[i] = 0.0;
        }
    }
	printGrid(u);

	// 迭代计算			--- Iterative calculation
	for (int t = 1; t <= T; t++) {
        // 边界条件：固定浓度	--- Boundary condition: fixed concentration
        u_new[0] = u[0];
        u_new[N] = u[N];

        // 内部节点计算		--- Internal node calculation
        for (int i = 1; i < N; i++) {
            u_new[i] = u[i] + alpha * dt / (dx*dx) * (u[i+1] - 2*u[i] + u[i-1]);
        }

        // 更新浓度分布		--- Update concentration distribution
        for (int i = 0; i <= N; i++) {
            u[i] = u_new[i];
        }
	printGrid(u);
    }
    return 0;
}

